@@ -1,4 +1,4 @@
-from .api_exception import REPORT_LEVEL, APIError, APIException, ErrorCodeBase
+from .api_exception import REPORT_LEVEL, APIError, APIException, ErrorCodeBase, ProxyErrorCode
 from .api_exception_handler import APIExceptionHandler
 from .api_exception_manager import APIExceptionManager
 from .api_exception_middleware import APIExceptionMiddleware
@@ -10,5 +10,6 @@ __all__ = [
     "APIExceptionHandler",
     "APIExceptionMiddleware",
     "ErrorCodeBase",
+    "ProxyErrorCode",
     "REPORT_LEVEL",
 ]
